@@ -1,6 +1,3 @@
-
-
-
 ;*******************************************************************************
 ;*                                                                             *
 ;*  copyright (c) 1988 kent state univ.  kent, ohio 44242                      *
@@ -9,7 +6,7 @@
 
 (when (null (fboundp 'wrs)) (load "convmac.lisp"))
 
-(declare (special *gentran-dir tempvartype* tempvarname* tempvarnum* genstmtno*
+(declare-top (special *gentran-dir tempvartype* tempvarname* tempvarnum* genstmtno*
 	genstmtincr* *symboltable* *instk* *stdin* *currin* *outstk*
 	*stdout* *currout* *outchanl* *lispdefops* *lisparithexpops*
 	*lisplogexpops* *lispstmtops* *lispstmtgpops*))
@@ -32,7 +29,6 @@
 (put 'quotient '*ratforprecedence* 6)
 (put 'minus    '*ratforprecedence* 7)
 (put 'expt     '*ratforprecedence* 8)
-(print "bar") (terpri)
 (put 'or       '*ratforop* "||")
 (put 'and      '*ratforop* '|&|)
 (put 'not      '*ratforop* '|!|)
@@ -40,7 +36,6 @@
 (put 'notequal '*ratforop* '|!=|)
 (put 'greaterp '*ratforop* '|>|)
 (put 'geqp     '*ratforop* '|>=|)
-(print "foo")
 (put 'lessp    '*ratforop* '|<|)
 (put 'leqp     '*ratforop* '|<=|)
 (put 'plus     '*ratforop* '|+|)
@@ -64,7 +59,7 @@
                         ((equal f '$end_group)
 			 (mkfratendgp))
                         (t
-			 (ratexp f))))
+			 (ratexpgen f))))
 		 ((or (lispstmtp f) (lispstmtgpp f))
 		  (cond (*gendecs
 			 (prog (r)
@@ -78,7 +73,7 @@
 		 ((lispdefp f)
 		  (ratsubprog f))
 		 (t
-		  (ratexp f)))))
+		  (ratexpgen f)))))
 
 ;;  subprogram translation  ;;
 
@@ -127,29 +122,29 @@
 
 ;;  expression translation  ;;
 
-(defun ratexp (exp)
-  (ratexp1 exp 0))
+(defun ratexpgen (exp)
+  (ratexpgen1 exp 0))
 
-(defun ratexp1 (exp wtin)
+(defun ratexpgen1 (exp wtin)
   (cond ((atom exp) (list (ratforname exp)))
 	((eq (car exp) 'literal) (ratliteral exp))
 	((onep (length exp)) exp)
-	((memq (car exp) '(minus not))
+	((member (car exp) '(minus not) :test #'eq)
 	 (let* ((wt (ratforprecedence (car exp)))
-		(res (cons (ratforop (car exp)) (ratexp1 (cadr exp) wt))))
+		(res (cons (ratforop (car exp)) (ratexpgen1 (cadr exp) wt))))
 	       (cond ((< wt wtin) (aconc (cons '|(| res) '|)|))
 		     (t res))))
-	((or (memq (car exp) *lisparithexpops*)
-	     (memq (car exp) *lisplogexpops*))
+	((or (member (car exp) *lisparithexpops* :test #'eq)
+	     (member (car exp) *lisplogexpops* :test #'eq))
 	 (let* ((wt (ratforprecedence (car exp)))
 		(op (ratforop (car exp)))
-		(res (ratexp1 (cadr exp) wt))
+		(res (ratexpgen1 (cadr exp) wt))
 		(res1))
 	       (setq exp (cdr exp))
 	       (cond ((eq op '+)
 		      (while (setq exp (cdr exp))
                          (progn
-			  (setq res1 (ratexp1 (car exp) wt))
+			  (setq res1 (ratexpgen1 (car exp) wt))
 			  (cond ((or (eq (car res1) '-)
 				     (and (numberp (car res1))
 					  (minusp (car res1))))
@@ -160,14 +155,14 @@
 		      (while (setq exp (cdr exp))
                          (setq res (append res
 					   (cons op
-						 (ratexp1 (car exp) wt)))))))
+						 (ratexpgen1 (car exp) wt)))))))
 	       (cond ((< wt wtin) (aconc (cons '|(| res) '|)|))
 		     (t res))))
 	(t
-	 (let ((res (cons (car exp) (cons '|(| (ratexp1 (cadr exp) 0)))))
+	 (let ((res (cons (car exp) (cons '|(| (ratexpgen1 (cadr exp) 0)))))
               (setq exp (cdr exp))
 	      (while (setq exp (cdr exp))
-                 (setq res (append res (cons '|,| (ratexp1 (car exp) 0)))))
+                 (setq res (append res (cons '|,| (ratexpgen1 (car exp) 0)))))
               (aconc res '|)| )))))
 
 (defun ratforname (name)
@@ -218,7 +213,7 @@
 	(setq r (mkfratdo var lo hi incr))
 	(indentratlevel (+ 1))
 	(setq r (append r (ratstmt body)))
-	(indentratlevel (minus 1))
+	(indentratlevel (- 1))
 	(return r)))
 
 (defun ratend (stmt)
@@ -236,7 +231,7 @@
 	       (setq r (mkfratfor var lo cond nil nil))))
 	(indentratlevel (+ 1))
 	(setq r (append r (ratstmt body)))
-	(indentratlevel (minus 1))
+	(indentratlevel (- 1))
 	(return r)))
 
 (defun ratgoto (stmt)
@@ -255,10 +250,10 @@
 		    (equal (length st) 2))
 	       (setq st (mkstmtgp 0 (list st)))))
 	(setq r (append r (ratstmt st)))
-	(indentratlevel (minus 1))
+	(indentratlevel (- 1))
 	(setq stmt (cdr stmt))
 	(while (and (setq stmt (cdr stmt))
-		    (neq (caar stmt) t))
+		    (not (eq (caar stmt) t)))
 	       (progn
 		(setq r (append r (mkfratelseif (caar stmt))))
 		(indentratlevel (+ 1))
@@ -268,7 +263,7 @@
 			    (equal (length st) 2))
 		       (setq st (mkstmtgp 0 (list st)))))
 		(setq r (append r (ratstmt st)))
-		(indentratlevel (minus 1))))
+		(indentratlevel (- 1))))
 	(cond (stmt
 	       (progn
 		(setq r (append r (mkfratelse)))
@@ -279,7 +274,7 @@
 			    (equal (length st) 2))
 		       (setq st (mkstmtgp 0 (list st)))))
 		(setq r (append r (ratstmt st)))
-		(indentratlevel (minus 1)))))
+		(indentratlevel (- 1)))))
 	(return r)))
 
 (defun ratliteral (stmt)
@@ -324,7 +319,7 @@
 	(setq r (mkfratrepeat))
 	(indentratlevel (+ 1))
 	(setq r (append r (ratstmt body)))
-	(indentratlevel (minus 1))
+	(indentratlevel (- 1))
 	(return (append r (mkfratuntil exitcond)))))
 
 (defun ratreturn (stmt)
@@ -339,7 +334,7 @@
 	(setq r (mkfratbegingp))
 	(indentratlevel (+ 1))
 	(setq r (append r (foreach stmt in stmtgp conc (ratstmt stmt))))
-	(indentratlevel (minus 1))
+	(indentratlevel (- 1))
 	(return (append r (mkfratendgp)))))
 
 (defun ratstmtno (label)
@@ -358,7 +353,7 @@
 	(setq r (mkfratwhile cond))
 	(indentratlevel (+ 1))
 	(setq r (append r (ratstmt body)))
-	(indentratlevel (minus 1))
+	(indentratlevel (- 1))
 	(return r)))
 
 (defun ratwrite (stmt)
@@ -373,8 +368,8 @@
 ;;  statement formatting  ;;
 
 (defun mkfratassign (lhs rhs)
-  (append (append (cons (mkrattab) (ratexp lhs))
-		  (cons '= (ratexp rhs)))
+  (append (append (cons (mkrattab) (ratexpgen lhs))
+		  (cons '= (ratexpgen rhs)))
 	  (list (mkterpri))))
 
 (defun mkfratbegingp ()
@@ -388,10 +383,10 @@
    (cond (params
 	  (setq params (append (append (list '|(|)
 				       (foreach p in (insertcommas params)
-						conc (ratexp p)))
+						conc (ratexpgen p)))
 			       (list '|)|)))))
    (append (append (list (mkrattab) 'call '| |)
-		   (ratexp fname))
+		   (ratexpgen fname))
 	   (append params
 		   (list (mkterpri))))))
 
@@ -401,7 +396,7 @@
 (defun mkfratdec (type varlist)
   (progn
    (setq type (or type 'dimension))
-   (setq varlist (foreach v in (insertcommas varlist) conc (ratexp v)))
+   (setq varlist (foreach v in (insertcommas varlist) conc (ratexpgen v)))
    (cond ((implicitp type)
 	  (append (list (mkrattab) type '| |  '|(|)
                   (append varlist (list '|)| (mkterpri)))))
@@ -414,11 +409,11 @@
    (cond ((onep incr)
 	  (setq incr nil))
 	 (incr
-	  (setq incr (cons '|,| (ratexp incr)))))
+	  (setq incr (cons '|,| (ratexpgen incr)))))
    (append (append (append (list (mkrattab) 'do '| |)
-			   (ratexp var))
-		   (append (cons '|=| (ratexp lo))
-			   (cons '|,| (ratexp hi))))
+			   (ratexpgen var))
+		   (append (cons '|=| (ratexpgen lo))
+			   (cons '|,| (ratexpgen hi))))
 	   (append incr
 		   (list (mkterpri))))))
 
@@ -427,7 +422,7 @@
 
 (defun mkfratelseif (exp)
   (append (append (list (mkrattab) 'else '| | 'if '| | '|(|)
-		  (ratexp exp))
+		  (ratexpgen exp))
 	  (list '|)| (mkterpri))))
 
 (defun mkfratend ()
@@ -439,11 +434,11 @@
 (defun mkfratfor (var1 lo cond var2 nextexp)
   (progn
    (cond (var1
-	  (setq var1 (append (ratexp var1) (cons '= (ratexp lo))))))
+	  (setq var1 (append (ratexpgen var1) (cons '= (ratexpgen lo))))))
    (cond (cond
-	  (setq cond (ratexp cond))))
+	  (setq cond (ratexpgen cond))))
    (cond (var2
-	  (setq var2 (append (ratexp var2) (cons '= (ratexp nextexp))))))
+	  (setq var2 (append (ratexpgen var2) (cons '= (ratexpgen nextexp))))))
    (append (append (append (list (mkrattab) 'for '| |  '|(|)
 			   var1)
 		   (cons '|;| cond))
@@ -455,26 +450,26 @@
 
 (defun mkfratif (exp)
   (append (append (list (mkrattab) 'if '| |  '|(|)
-		  (ratexp exp))
+		  (ratexpgen exp))
 	  (list '|)| (mkterpri))))
 
 (defun mkfratliteral (args)
   (foreach a in args conc
 	   (cond ((equal a '$tab) (list (mkrattab)))
 		 ((equal a '$cr) (list (mkterpri)))
-		 ((listp a) (ratexp a))
+		 ((listp a) (ratexpgen a))
 		 (t (list a)))))
 
 (defun mkfratread (var)
   (append (list (mkrattab) 'read '|(*,*)| '| | )
-	  (append (ratexp var) (list (mkterpri)))))
+	  (append (ratexpgen var) (list (mkterpri)))))
 
 (defun mkfratrepeat ()
   (list (mkrattab) 'repeat (mkterpri)))
 
 (defun mkfratreturn (exp)
   (cond (exp
-	 (append (append (list (mkrattab) 'return '|(|) (ratexp exp))
+	 (append (append (list (mkrattab) 'return '|(|) (ratexpgen exp))
 		 (list '|)| (mkterpri))))
 	(t
 	 (list (mkrattab) 'return (mkterpri)))))
@@ -487,27 +482,27 @@
    (cond (params
 	  (setq params (aconc (cons '|(|
 				    (foreach p in (insertcommas params)
-					     conc (ratexp p)))
+					     conc (ratexpgen p)))
 			      '|)|))))
    (cond (type
 	  (setq type (list (mkrattab) type '| |  stype '| | )))
 	 (t
 	  (setq type (list (mkrattab) stype '| | ))))
-   (append (append type (ratexp name))
+   (append (append type (ratexpgen name))
 	   (aconc params (mkterpri)))))
 
 (defun mkfratuntil (logexp)
   (append (list (mkrattab) 'until '| |  '|(|)
-	  (append (ratexp logexp) (list '|)| (mkterpri)))))
+	  (append (ratexpgen logexp) (list '|)| (mkterpri)))))
 
 (defun mkfratwhile (exp)
   (append (append (list (mkrattab) 'while '| |  '|(|)
-		  (ratexp exp))
+		  (ratexpgen exp))
 	  (list '|)| (mkterpri))))
 
 (defun mkfratwrite (arglist)
   (append (append (list (mkrattab) 'write '|(*,*)| '| | )
-		  (foreach arg in (insertcommas arglist) conc (ratexp arg)))
+		  (foreach arg in (insertcommas arglist) conc (ratexpgen arg)))
 	  (list (mkterpri))))
 
 ;;  indentation control  ;;
