@@ -16,7 +16,7 @@
 		      valflag $gcd pl0 d0 degd0 var
 		      many* tempprime ovarlist valist modulus
 		      zl *prime plim nn* ne nn*-1 dlp
-		      ez1skip svalsl nsvals errrjfflag $algebraic
+		      ez1skip svalsl nsvals $algebraic
 		      lc1 oldlc limk *alpha $ratfac))
 
 (load-macsyma-macros ratmac)
@@ -146,7 +146,8 @@
 		  maximize (multideg x)))
      (setq zfactr (z1 builder (car factrs) (cadr factrs)))
      (setq zfactr (pmod (oldrep (car zfactr))))
-     (return (cadr ((lambda (modulus) (fastcont zfactr)) nil)))))
+     (return (cadr (let ((modulus nil))
+		     (fastcont zfactr))))))
 
 (defun getd0 (tpl tvals)
   (prog (c)
@@ -359,10 +360,9 @@
      (go loop)))
 
 (defun eztestdivide (x y)
-  (let ((errrjfflag t))
-    (cond ((or (pcoefp x) (pcoefp y)
-	       (catch 'raterr (pquotient (car (last x)) (car (last y)))))
-	   (catch 'raterr (pquotient x y))))))
+  (when (or (pcoefp x) (pcoefp y)
+            (ignore-rat-err (pquotient (car (last x)) (car (last y)))))
+    (ignore-rat-err (pquotient x y))))
 
 (defun noterms (p)
   (cond ((pcoefp p) 1)
@@ -375,7 +375,8 @@
      (cond ((univar (cdr p)) (return (oldcontent p)))
 	   (t (setq oldgenvar genvar)
 	      (setq var (car p))
-	      (setq genvar (remove var (intersection (cdr genvar) (listovars p) :test #'equal)
+	      ;; intersect must maintain order of genvar list
+	      (setq genvar (remove var (intersect (cdr genvar) (listovars p))
 				   :test #'equal))))
      (cond ((pminusp p) (setq p (pminus p) minus? t)))
      (setq tppl (oddelm (cddr p)))
