@@ -312,6 +312,8 @@
   (setq e (simplifya (specrepcheck (second e)) z))
   (cond (($featurep e '$integer) e) ;; takes care of round(round(x)) --> round(x).
 	((member e '($inf $minf $und $ind) :test #'eq) e)
+	((eq e '$zerob) 0)
+	((eq e '$zeroa) 0)
 	(t 
 	 (let* ((lb (take '($floor) e))
 		(ub (take '($ceiling) e))
@@ -343,6 +345,8 @@
   (setq e (simplifya (specrepcheck (second e)) z))
   (cond (($featurep e '$integer) e) ;; takes care of truncate(truncate(x)) --> truncate(x).
 	((member e '($inf $minf $und $ind) :test #'eq) e)
+	((eq e '$zerob) 0)
+	((eq e '$zeroa) 0)
 	(t
 	 (let ((sgn (csign e)))
 	   (cond ((member sgn '($neg $nz) :test #'eq) (take '($ceiling) e))
