@@ -21,11 +21,7 @@
   (setq old-ibase *read-base* old-base *print-base*)
   (setq *read-base* 10. *print-base* 10.))
 
-;; Store build-in operators, which get additional properties.
-;; These operators aren't killed by the function kill-operator.
-(defvar *mopl* nil)
-
-(declare-top  (special bindlist loclist errset
+(declare-top  (special bindlist loclist errset *mopl*
 		       $values $functions $arrays $gradefs $dependencies
 		       $rules $props $ratvars
 		       varlist genvar
